Documentation
¶
Index ¶
- func AddToTomb(tx *sqlx.Tx, table string, id string) error
- func Create(tx *sqlx.Tx, table string, params map[string]interface{}) error
- func Delete(tx *sqlx.Tx, table string, id string) error
- func DeleteBy(tx *sqlx.Tx, table string, conditions map[string]interface{}) error
- func Get(tx *sqlx.Tx, table string, id string, dest interface{}) error
- func GetAll(tx *sqlx.Tx, table string, dest interface{}) error
- func GetAllBy(tx *sqlx.Tx, table string, conditions map[string]interface{}, dest interface{}) error
- func GetAllByCaseInsensitive(tx *sqlx.Tx, table string, conditions map[string]interface{}, dest interface{}) error
- func GetBy(tx *sqlx.Tx, table string, conditions map[string]interface{}, dest interface{}) error
- func GetByCaseInsensitive(tx *sqlx.Tx, table string, conditions map[string]interface{}, dest interface{}) error
- func GetByName(tx *sqlx.Tx, table string, name string, dest interface{}) error
- func GetByNameCaseInsensitive(tx *sqlx.Tx, table string, name string, dest interface{}) error
- func MarkAsDeleted(tx *sqlx.Tx, table string, id string) error
- func Rename(tx *sqlx.Tx, table string, id string, newName string) error
- func Restore(tx *sqlx.Tx, table string, id string) error
- func Update(tx *sqlx.Tx, table string, id string, params map[string]interface{}) error
- func UpdateBy(tx *sqlx.Tx, table string, conditions map[string]interface{}, ...) error
- func UpdateMtime(tx *sqlx.Tx, table string, id string, mtime int64) error
- func XDeleteBy(tx *sqlx.Tx, table string, conditions map[string]interface{}) error
- type Table
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetAllByCaseInsensitive ¶
func GetAllByCaseInsensitive(tx *sqlx.Tx, table string, conditions map[string]interface{}, dest interface{}) error
GetAllByCaseInsensitive retrieves all records by multiple column and value conditions case insensitively
func GetByCaseInsensitive ¶
func GetByCaseInsensitive(tx *sqlx.Tx, table string, conditions map[string]interface{}, dest interface{}) error
GetByCaseInsensitive retrieves a record by multiple column and value conditions case insensitively
Types ¶
Click to show internal directories.
Click to hide internal directories.